#
# spec file for package ebtables
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           ebtables
VCS: https://src.suse.de/ALP-pool/ebtables#f36659b0574ebf7666b3c8a3860c4b704bf32e90
Version:        2.0.11
Release:        3.1
Summary:        Ethernet Bridge Tables
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Security
URL:            http://ebtables.sf.net/
#Git-Clone:	git://git.netfilter.org/ebtables
Source0:        http://ftp.netfilter.org/pub/ebtables/ebtables-%{version}.tar.gz
Source1:        http://ftp.netfilter.org/pub/ebtables/ebtables-%{version}.tar.gz.sig
Source2:        ebtables.keyring
Source3:        ebtables.service
Source4:        ebtables.systemd
BuildRequires:  linux-glibc-devel >= 2.6.20
BuildRequires:  sed
BuildRequires:  systemd-rpm-macros
BuildRequires:  xz
Requires:       netcfg >= 11.6 libnss_usrfiles2
Requires(pre):  %fillup_prereq
%{?systemd_ordering}
%if %{with libalternatives}
BuildRequires:  alts
Requires:       alts
%else
Requires(post): update-alternatives
Requires(postun):update-alternatives
%endif

%description
A firewalling tool to transparently filter network traffic passing a
bridge. The filtering possibilities are limited to link layer filtering
and some basic filtering on higher network layers. The ebtables tool
can be used together with the other Linux filtering tools, like
iptables. There are no incompatibility issues.

%package -n libebtc0
Summary:        Library for the ebtables low-level ruleset generation and parsing
Group:          System/Libraries

%description -n libebtc0
libebtc ("ebtables cache") is used to retrieve from the kernel, parse,
construct, and load rulesets into the kernel.

%prep
%autosetup -p1

# delete all kernel headers, but keep ebt_ip6.h and ebt_nflog.h
mv include/linux/netfilter_bridge/ebt_ip6.{h,h.save}
mv include/linux/netfilter_bridge/ebt_nflog.{h,h.save}
mv include/linux/netfilter_bridge/ebt_ulog.{h,h.save}
rm -f include/linux/*.h
rm -f include/linux/netfilter_bridge/*.h
mv include/linux/netfilter_bridge/ebt_ip6.{h.save,h}
mv include/linux/netfilter_bridge/ebt_nflog.{h.save,h}
mv include/linux/netfilter_bridge/ebt_ulog.{h.save,h}

%build
# The way ebtables is built requires ASNEEDED=0 forever [bnc#567267]
export SUSE_ASNEEDED=0
%configure
%make_build

%install
# The way ebtables is built requires ASNEEDED=0 forever [bnc#567267]
export SUSE_ASNEEDED=0
mkdir -p "%{buildroot}/%{_sysconfdir}/init.d"
%make_install
mkdir -p %{buildroot}%{_fillupdir}
mkdir -p %{buildroot}%{_unitdir}
install -p %{_sourcedir}/ebtables.service %{buildroot}%{_unitdir}/
sed -i "s|@LIBEXECDIR@|%{_libexecdir}|g" %{buildroot}%{_unitdir}/*.service
chmod -x %{buildroot}%{_unitdir}/*.service
mkdir -p %{buildroot}%{_libexecdir}
install -m0755 %{_sourcedir}/ebtables.systemd %{buildroot}%{_libexecdir}/%{name}-helper
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
touch %{buildroot}%{_fillupdir}/sysconfig.%{name}.filter
touch %{buildroot}%{_fillupdir}/sysconfig.%{name}.nat
touch %{buildroot}%{_fillupdir}/sysconfig.%{name}.broute
rm -rfv %{buildroot}%{_initddir}
# not used
rm -f "%{buildroot}/%{_sysconfdir}/ebtables-config"
for i in ebtables ebtables-restore ebtables-save; do
%if ! %{with libalternatives}
        ln -fsv "%{_sysconfdir}/alternatives/$i" "%{buildroot}/%{_sbindir}/$i"
%else
        ln -fsv  %{_bindir}/alts "%{buildroot}/%{_sbindir}/$i"
%endif
done
echo ".so ebtables-legacy.8" >"%{buildroot}/%{_mandir}/man8/ebtables.8"
# no headers to make use of it
rm -f "%{buildroot}/%{_libdir}/libebtc.la" "%{buildroot}/%{_libdir}/libebtc.so"

%if %{with libalternatives}
mkdir -p %{buildroot}%{_datadir}/libalternatives/ebtables
cat > %{buildroot}%{_datadir}/libalternatives/ebtables/1.conf <<EOF
binary=%{_sbindir}/ebtables-legacy
group=ebtables, ebtables-restore, ebtables-save
EOF
mkdir -p %{buildroot}%{_datadir}/libalternatives/ebtables-restore
cat > %{buildroot}%{_datadir}/libalternatives/ebtables-restore/1.conf <<EOF
binary=%{_sbindir}/ebtables-legacy-restore
group=ebtables, ebtables-restore, ebtables-save
EOF
mkdir -p %{buildroot}%{_datadir}/libalternatives/ebtables-save
cat > %{buildroot}%{_datadir}/libalternatives/ebtables-save/1.conf <<EOF
binary=%{_sbindir}/ebtables-legacy-save
group=ebtables, ebtables-restore, ebtables-save
EOF
%endif

%pre
%if %{with libalternatives}
# removing old update-alternatives entries
if [ "$1" -gt 0 ] && [ -f %{_sbindir}/update-alternatives ] ; then
         update-alternatives --remove ebtables "%{_sbindir}/ebtables-legacy"
fi
%endif
%service_add_pre %{name}.service

%post
%if ! %{with libalternatives}
update-alternatives --force \
	--install "%{_sbindir}/ebtables" ebtables "%{_sbindir}/ebtables-legacy" 1 \
	--slave "%{_sbindir}/ebtables-restore" ebtables-restore "%{_sbindir}/ebtables-legacy-restore" \
	--slave "%{_sbindir}/ebtables-save" ebtables-save "%{_sbindir}/ebtables-legacy-save"
%endif
%service_add_post %{name}.service
%fillup_only

%preun
%service_del_preun %{name}.service

%postun
%if ! %{with libalternatives}
if test "$1" = 0; then
	update-alternatives --remove ebtables "%{_sbindir}/ebtables-legacy"
fi
%endif
%service_del_postun %{name}.service

%post   -n libebtc0 -p /sbin/ldconfig
%postun -n libebtc0 -p /sbin/ldconfig

%files
%license COPYING
%doc ChangeLog
%{_mandir}/man8/ebtables*.8%{?ext_man}
%{_libexecdir}/%{name}-helper
%{_unitdir}/%{name}.service
%if ! %{with libalternatives}
%ghost %{_sysconfdir}/alternatives/ebtables
%ghost %{_sysconfdir}/alternatives/ebtables-restore
%ghost %{_sysconfdir}/alternatives/ebtables-save
%else
%dir %{_datadir}/libalternatives
%dir %{_datadir}/libalternatives/ebtables
%dir %{_datadir}/libalternatives/ebtables-restore
%dir %{_datadir}/libalternatives/ebtables-save
%{_datadir}/libalternatives/ebtables/1.conf
%{_datadir}/libalternatives/ebtables-restore/1.conf
%{_datadir}/libalternatives/ebtables-save/1.conf
%endif
%ghost %{_fillupdir}/sysconfig.%{name}.filter
%ghost %{_fillupdir}/sysconfig.%{name}.nat
%ghost %{_fillupdir}/sysconfig.%{name}.broute
# is provided by the netcfg package
%exclude %{_sysconfdir}/ethertypes
%{_sbindir}/ebtables*
%{_sbindir}/rcebtables

%files -n libebtc0
%{_libdir}/libebtc.so.0*

%changelog
* Thu Nov 11 2021 danilo.spinella@suse.com
- Add build dependency on libalternatives
- Run spec-cleaner
* Fri Oct 15 2021 jsegitz@suse.com
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * ebtables.service
* Fri Aug 20 2021 schubi@suse.de
- Use libalternatives instead of update-alternatives.
* Wed Sep  2 2020 dimstar@opensuse.org
- Have the source .service file hold a placeholder for LIBEXECDIR,
  which we replace during build/install phase, allowing the package
  to be used no matter what value %%{_libexecdir} has.
* Tue Sep  1 2020 kstreitova@suse.com
- replace /usr/lib with /usr/libexec in .service files to follow
  %%_libexecdir macro changes
* Tue May  5 2020 kukuk@suse.com
- Revert last /bin/bash -> /bin/sh change
* Wed Apr 29 2020 kukuk@suse.com
- Use /bin/sh for ebtables.systemd
- Don't hard require systemd, we don't need that in a container
* Fri Jan 10 2020 kstreitova@suse.com
- rename /usr/lib/ebtables helper file to /usr/lib/ebtables-helper
  otherwise it conflicts with /usr/lib/ebtables library directory
  on 32-bit systems [bsc#1159769]
* Tue Dec 10 2019 kstreitova@suse.com
- add ebtables.keyring as a Source
* Mon Dec  2 2019 jengelh@inai.de
- Update to release 2.0.11
  * Add --noflush command line support for ebtables-restore
  * Do not print IPv6 mask if it is all ones
  * Allow RETURN target rules in user defined chains
  * ebt_ip: add support for matching ICMP type and code
  * ebt_ip: add support for matching IGMP type
  * extensions: Add string filter to ebtables
  * Print IPv6 prefixes in CIDR notation
  * extensions: Add AUDIT target
  * Fix incorrect IPv6 prefix formatting
- Drop ebtables-v2.0.8-makefile.diff (no longer needed)
- Drop ebtables-v2.0.8-initscript.diff, include-linux-if.patch
  (not applicable)
- Drop ebtables-v2.0.10-4-audit.patch,
  0001-fix-compilation-warning.patch,
  0001-Use-flock-for-concurrent-option.patch,
  0002-Fix-locking-if-LOCKDIR-does-not-exist.patch (merged)
* Wed Jul 10 2019 kstreitova@suse.com
- fix path (/sbin -> /usr/sbin) in ebtables.systemd [bsc#1140898]
* Fri Feb 22 2019 mrostecki@opensuse.org
- Add upstream patches which improve handling stale locks.
  (boo#1126094)
  * 0001-Use-flock-for-concurrent-option.patch
  * 0002-Fix-locking-if-LOCKDIR-does-not-exist.patch
* Fri Aug 24 2018 jengelh@inai.de
- Move ebtables to ebtables-legacy and use update-alternatives to
  offer a selection mechanism.
* Thu Mar 15 2018 kstreitova@suse.com
- fix ExecStart/ExecStop path in ebtables.service [bnc#1085228]
* Mon Mar 12 2018 matthias.gerstner@suse.com
- Fix ethertypes ownership, should be %%exclude, not %%ghost.
* Thu Feb 22 2018 matthias.gerstner@suse.com
- Resolve conflict with iptables-nft and obtain ethertypes from new netcfg
  minor version. FATE#320520
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Mar 23 2017 kstreitova@suse.com
- cleanup with spec-cleaner
- get rid of %%{name} macros in the patch names
- remove sysvinit support
* Fri May  6 2016 p.drouand@gmail.com
- Add systemd support for openSUSE > 12.10
- Do not depend on fillup when building with sysvinit support; the
  package doesn't provide any sysconfig file
- Change Requires(post) tag for Requires(pre); sysvinit must be
  available before the package installation, according to the policy
* Tue Apr 26 2016 kstreitova@suse.com
- add "Requires(post): %%insserv_prereq %%fillup_prereq" to fix
  problem with missing sed during the installation [bnc#976919]
- remove non-break space from specfile
- use spec-cleaner to clean the specfile
* Sat Aug 29 2015 bwiedemann@suse.com
- fix compilation
  add include-linux-if.patch 0001-fix-compilation-warning.patch
* Tue Jun 16 2015 kstreitova@suse.com
- add ebtables-v2.0.10-4-audit.patch needed for CC certification
  [bnc#934680]
* Thu Nov 13 2014 dimstar@opensuse.org
- Also save include/linux/netfilter_bridge/ebt_ulog.h, as it no
  longer exists in the mainline kernel.
* Tue Sep 23 2014 jengelh@inai.de
- Remove support for old distros from specfile
  (prjconf can do substitutions instead)
* Fri Feb 28 2014 vcizek@suse.com
- add missing BuildRequires: sed (bnc#865848)
* Wed Dec 19 2012 jengelh@inai.de
- Have build succeed on non-SUSE
* Thu Dec 15 2011 jengelh@medozas.de
- Update to new upstream release 2.0.10.4
  * previous counter bug was still present and has been addressed now
* Sun Dec  4 2011 jengelh@medozas.de
- Update to new upstream release 2.0.10.3
  * fix a counter setting bug
* Thu Aug 11 2011 jengelh@medozas.de
- Update to new upstream release 2.0.10.2
  * minor compilation fixes: respect LDFLAGS in Makefiles
- Remove obsolete ebtables-typepuns.diff patch (fixed upstream)
* Sun Jul 10 2011 jengelh@medozas.de
- update to 2.0.10.1
  * fix --among-dst-file, which translated to --among-src
  * Makefile: respect LDFLAGS during ebtables build
  * Makefile: create directories to avoid build failure when DESTDIR
  is supplied
  * incorporate fixes for possible issues found by Coverity analysis
  * extend ebt_ip6 to allow matching on ipv6-icmp types/codes
  * add --concurrent option, which enables using a file lock to
  support concurrent scripts updating the ebtables kernel tables
- run spec-beautifier over specfile
* Mon Jun  6 2011 puzel@novell.com
- update to 2.0.9-2
  * fix unwanted zeroing of counters in the last user-defined chain
  * fix hidden symbol compilation error when using ld directly
  * fix return value checking of creat to give a correct error
    message if the atomic file couldn't be created
  * correct info in INSTALL about compilation of ulog
- use spec-cleaner
- update ebtables-v2.0.8-makefile.diff
- license is GPLv2, not GPLv2+
- package COPYING and ChangeLog files
* Tue May 31 2011 lnussel@suse.de
- cleanup up initscript
  * don't use /var/lock/subsys
  * read /etc/sysconfig/ebtables for setting and restore state from
    /etc/ebtables where the script actually saved the state to.
* Thu Mar 18 2010 coolo@novell.com
- use rc_status (uncredited change)
* Mon Jan 25 2010 jengelh@medozas.de
- Switch to SUSE_ASNEEDED=0 to fix segmentation fault/NULL dereference
  (caused by plugins not being loaded, due to them not being linked in)
  [bnc#567267]
* Wed Jan  6 2010 prusnak@suse.cz
- update to 2.0.9-1
  * added ip6 module for filtering IPv6 traffic
  * added --log-ip6 option for logging IPv6 traffic
  * added nflog watcher for logging packets to userspace
  * bugfix in ebtables.sysv
  * bugfix for among match on x86-64
- fix scriptlets in spec
- fix init script
* Sat Aug 30 2008 cthiel@suse.de
- fix init script
* Wed Oct 24 2007 ro@suse.de
- fix build (use gcc not ld directly)
* Wed Oct 17 2007 prusnak@suse.cz
- fixed specfile not to include debug files in normal package
* Fri Oct 12 2007 prusnak@suse.cz
- update to 2.0.8-2
  * add sysconfig support (ebtables-save, ebtables-restore, etc)
  * add ulog watcher
  * use shared libraries (making the code easily usable by third parties)
  * improve speed
  * bugfixes, dccp and sctp support
- dropped obsolete patches:
  * gcc.diff (included in update)
* Thu Aug  9 2007 olh@suse.de
- remove private include/linux/ files
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jun 29 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Thu Apr 21 2005 postadal@suse.cz
- fixed for gcc 4.0
* Fri Jun 18 2004 postadal@suse.cz
- new package v2.0.6
